@@ -86,4 +86,4 @@ def determine_model(model):
         if isinstance(model, mxnet.gluon.nn.Block):
             return "mxnet"
     finally:
-        return ""
+        raise ValueError("Could not determine framework model is from. Please specify explicitly.")
