@@ -43,4 +43,6 @@ def trainApi(model_id, train_id, test_id, optimiser, loss, batch_size, epochs, t
     elif model_id != "" and not isinstance(model_id, Task):
         params["modelId"] = model_id
     response = requests.get(TRAIN_URL, params=params, json=optimiser)
+    if response.status_code != 200:
+        raise ValueError(response.text)
     return response
